﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Windows.Threading;
using Infragistics.Controls.Schedules;

namespace ScheduleTest
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
       InitializeComponent();

            Thread.CurrentThread.CurrentCulture = new System.Globalization.CultureInfo("en-US");
            ObservableCollection<Resource> resources =
             new ObservableCollection<Resource>();
            Resource resAmanda = new Resource() { Id = "own1", Name = "Amanda" };
            Resource resClark = new Resource() { Id = "own2", Name = "Clark" };
            resources.Add(resAmanda);
            resources.Add(resClark);

            ObservableCollection<ResourceCalendar> calendars = new ObservableCollection<ResourceCalendar>();
            ResourceCalendar calAmanda = new ResourceCalendar()
            {
                Id = "cal1",
                OwningResourceId = "own1"
            };
            calendars.Add(calAmanda); 
            ResourceCalendar calClark = new ResourceCalendar()
            {
                Id = "cal1",
                OwningResourceId = "own2"
            };
            calendars.Add(calClark);

            ObservableCollection<Appointment> appointments = new ObservableCollection<Appointment>();
            Appointment app1 = new Appointment()
            {
                Id = "t1",
                OwningResourceId = "own1",
                OwningCalendarId = "cal1",
                Subject = "Appointment 1",
                Description = "My first appointment",
                // Convert the date to universal time, because a time zone is not set
                // in this snippet    
                Start = DateTime.Today.AddHours(9).AddMinutes(12).ToUniversalTime(),
                End = DateTime.Today.AddHours(11).AddMinutes(42).ToUniversalTime()
            };
            appointments.Add(app1);

            Appointment app2 = new Appointment()
            {
                Id = "t2",
                OwningResourceId = "own2",
                OwningCalendarId = "cal1",
                Subject = "Appointment 2",
                Description = "My second appointment",
                // Convert the date to universal time, because a time zone is not set
                // in this snippet    
                Start = DateTime.Today.AddHours(10).AddMinutes(12).ToUniversalTime(),
                End = DateTime.Today.AddHours(11).AddMinutes(42).ToUniversalTime()
            };
            appointments.Add(app2);

            ListScheduleDataConnector dataConnector = new ListScheduleDataConnector();
            dataConnector.ResourceItemsSource = resources;
            dataConnector.ResourceCalendarItemsSource = calendars;
            dataConnector.AppointmentItemsSource = appointments;

            XamScheduleDataManager dataManager = new XamScheduleDataManager();
            dataManager.DataConnector = dataConnector;
            CalendarGroupCollection calGroups = dataManager.CalendarGroups;
            CalendarGroup calGroup = new CalendarGroup();

            calGroup.InitialCalendarIds = "own2[cal1]";
            calGroups.Add(calGroup);

            this.dayView.DataManager = dataManager; 
            //this.dayView
            DispatcherTimer timer = new DispatcherTimer();
            timer.Tick += new EventHandler(timer_Tick);
            timer.Interval = TimeSpan.FromSeconds(1);
            timer.Start();
        }

        void timer_Tick(object sender, EventArgs e)
        {
             
            DateTime min = dayView.VisibleDates.Min();
            DateTime max = dayView.VisibleDates.Max();

            DateTime curretn = DateTime.Now;
            DateTime startTime = new DateTime(
                min.Year,
                min.Month,
                min.Day,
                0, 0, 0);
            DateTime endTime = new DateTime(
                max.Year,
                max.Month,
                max.Day,
                23, 59, 59);



            var totalRange = endTime - startTime;
            var currentTimeRange = curretn - startTime;

            double currentTimePercentValue = currentTimeRange.Ticks / (double)totalRange.Ticks;
            double oneHourPercentValue = TimeSpan.FromHours(1).Ticks / (double)totalRange.Ticks;

            double scrolllMin = scrollBar.Minimum;
            double scrolllMax = scrollBar.Maximum;

            double srollRange = scrollBar.Maximum - scrollBar.Minimum;

            scrollBar.Value = (srollRange * currentTimePercentValue);
        }

        ScrollBar scrollBar;
        private void dayView_Loaded(object sender, RoutedEventArgs e)
        {
             
            scrollBar = Infragistics.Windows.Utilities.GetDescendantFromName(sender as DependencyObject, "TimeslotScrollBar") as ScrollBar;
            scrollBar.Background = Brushes.Red;
          
        }

   


    }

    public class MyConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {

            return ((DateTime)value).Hour + " " + ((DateTime)value).ToString("tt");
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }




    public class VM : INotifyPropertyChanged
    {
        private TimeSpan _dayOffset;

        public TimeSpan DayOffset
        {
            get
            {
                return _dayOffset;
            }

            set
            {
                _dayOffset = value;
                NotifyPropertyChanged("DayOffset");
            }
        }

        public VM(TimeSpan spam)
        {
            DayOffset = spam;
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void NotifyPropertyChanged(String info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }
        }
    }


}
